.. AUTO-GENERATED FILE -- DO NOT EDIT!

cluster
=======

Module: :mod:`cluster`
----------------------
.. automodule:: ISLP.cluster

.. currentmodule:: ISLP.cluster

.. autofunction:: ISLP.cluster.compute_linkage

